@@ -76,11 +76,13 @@
 ##' @param PA.dist.min (\emph{optional, default} \code{0}) \cr 
 ##' If pseudo-absence selection and \code{PA.strategy = 'disk'}, a \code{numeric} defining the 
 ##' minimal distance to presence points used to make the \code{disk} pseudo-absence selection 
-##' (in meters, see Details)
+##' (in the same projection system units as \code{resp.xy} and \code{expl.var}, see Details)
 ##' @param PA.dist.max (\emph{optional, default} \code{0}) \cr 
 ##' If pseudo-absence selection and \code{PA.strategy = 'disk'}, a \code{numeric} defining the 
 ##' maximal distance to presence points used to make the \code{disk} pseudo-absence selection 
-##' (in meters, see Details)
+##' (in the same projection system units as \code{resp.xy} and \code{expl.var}, see Details)
+##' @param PA.fact.aggr (\emph{optional, default} \code{NULL}) \cr
+##' If \code{strategy = 'random'} or \code{strategy = 'disk'}, a \code{integer} defining the factor of aggregation to reduce the resolution
 ##' @param PA.user.table (\emph{optional, default} \code{NULL}) \cr 
 ##' If pseudo-absence selection and \code{PA.strategy = 'user.defined'}, a \code{matrix} or 
 ##' \code{data.frame} with as many rows as \code{resp.var} values, as many columns as 
@@ -93,6 +95,8 @@
 ##' @param filter.raster (\emph{optional, default} \code{FALSE}) \cr 
 ##' If \code{expl.var} is of raster type, a \code{logical} value defining whether \code{resp.var} 
 ##' is to be filtered when several points occur in the same raster cell
+##' @param seed.val (\emph{optional, default} \code{NULL}) \cr 
+##' An \code{integer} value corresponding to the new seed value to be set
 ##' 
 ##' 
 ##' @return 
@@ -194,9 +198,10 @@
 ##'     otherwise it may lead to over-optimistic model evaluations and predictions !}
 ##'     }
 ##'     \item{disk}{pseudo-absences are selected within circles around presence points defined by 
-##'     \code{PA.dist.min} and \code{PA.dist.max} distance values (in meters). It allows to select 
-##'     pseudo-absence points that are not too close to (avoid same niche and pseudo-replication) 
-##'     or too far (localized sampling strategy) from presences.
+##'     \code{PA.dist.min} and \code{PA.dist.max} distance values (in the same projection system 
+##'     units as \code{coord} and \code{expl.var}). It allows to select pseudo-absence points that 
+##'     are not too close to (avoid same niche and pseudo-replication) or too far (localized 
+##'     sampling strategy) from presences.
 ##'     }
 ##'     \item{user.defined}{pseudo-absences are defined in advance and given as \code{data.frame} 
 ##'     through the \code{PA.user.table} parameter.
@@ -344,9 +349,11 @@ BIOMOD_FormatingData <- function(resp.name,
                                  PA.dist.min = 0,
                                  PA.dist.max = NULL,
                                  PA.sre.quant = 0.025,
+                                 PA.fact.aggr = NULL,
                                  PA.user.table = NULL,
                                  na.rm = TRUE,
-                                 filter.raster = FALSE)
+                                 filter.raster = FALSE,
+                                 seed.val = NULL)
 {
   .bm_cat(paste0(resp.name, " Data Formating"))
   
@@ -391,9 +398,11 @@ BIOMOD_FormatingData <- function(resp.name,
                                    PA.dist.min = PA.dist.min,
                                    PA.dist.max = PA.dist.max,
                                    PA.sre.quant = PA.sre.quant,
+                                   PA.fact.aggr = PA.fact.aggr,
                                    PA.user.table = PA.user.table,
                                    na.rm = na.rm,
-                                   filter.raster = filter.raster)
+                                   filter.raster = filter.raster,
+                                   seed.val)
   }
   .bm_cat("Done")
   return(out)
