@@ -75,7 +75,7 @@ setGeneric("BIOMOD.options.default", def = function(mod, typ, pkg, fun) { standa
 .BIOMOD.options.default.check.args <- function(mod, typ, pkg, fun)
 {
   ## check if model is supported
-  avail.models.list <- c('ANN', 'CTA', 'FDA', 'GAM', 'GBM', 'GLM', 'MARS', 'MAXENT', 'MAXNET', 'RF', 'SRE', 'XGBOOST')
+  avail.models.list <- c('ANN', 'CTA', 'FDA', 'GAM', 'GBM', 'GLM', 'MARS', 'MAXENT', 'MAXNET', 'RF','RFd', 'SRE', 'XGBOOST')
   .fun_testIfIn(TRUE, "mod", mod, avail.models.list)
   
   ## check if type is supported
@@ -283,7 +283,7 @@ setGeneric("BIOMOD.options.dataset",
   if (!is.null(bm.format)) {
     .fun_testIfInherits(TRUE, "bm.format", bm.format, c("BIOMOD.formated.data", "BIOMOD.formated.data.PA"))
   }
-  expected_CVnames <- "_allData_allRun"
+  expected_CVnames <- c("_allData_allRun")
   if (!is.null(calib.lines)) {
     .fun_testIfInherits(TRUE, "calib.lines", calib.lines, c("matrix"))
     
@@ -305,7 +305,17 @@ setGeneric("BIOMOD.options.dataset",
     }
   }
   if (strategy == "user.defined" && !is.null(user.val)) {
-    .fun_testIfIn(TRUE, "names(user.val)", names(user.val), expected_CVnames)
+    if ("for_all_datasets" %in% names(user.val)){
+      if (length(names(user.val)) > 1 ){
+        user.val <- user.val["for_all_datasets"]
+        cat("\n\t\t> Only the options defined for 'for_all_datasets' will be taken into account")
+      }
+      user.val <- rep(user.val, length(expected_CVnames))
+      names(user.val) <- expected_CVnames
+    }
+    
+    .fun_testIfIn(TRUE, "names(user.val)", names(user.val), c(expected_CVnames, "for_all_datasets"))
+    
     if (length(names(user.val)) != length(expected_CVnames)) {
       warning(paste0("Options will be changed only for a subset of datasets ("
                      , paste0(names(user.val), collapse = ", ")
@@ -316,7 +326,8 @@ setGeneric("BIOMOD.options.dataset",
   }
   
   return(list(strategy = strategy,
-              expected_CVnames = expected_CVnames))
+              expected_CVnames = expected_CVnames,
+              user.val = user.val))
 }
 
 # .BIOMOD.options.dataset.test <- function(bm.opt)
@@ -435,6 +446,9 @@ setMethod('BIOMOD.options.dataset', signature(strategy = 'character'),
                 argstmp$control = mgcv::gam.control()
               }
             }
+            if (mod == "GBM"){
+              argstmp$n.cores = 1
+            }
             if (mod == "GLM") {
               argstmp$family = binomial(link = 'logit')
               argstmp$control = list()
@@ -445,6 +459,11 @@ setMethod('BIOMOD.options.dataset', signature(strategy = 'character'),
               argstmp$mtry = 1
               argstmp$type <- "classification"
             }
+            if (mod == "RFd") {
+              argstmp[["x"]] = NULL
+              argstmp$mtry = 1
+              argstmp$type <- "classification"
+            }
             if (mod == "XGBOOST") { argstmp$nrounds = 4 }
             
             argstmp[["..."]] = NULL
