@@ -585,11 +585,11 @@ setMethod("get_built_models", "BIOMOD.models.out",
 
 setMethod("get_evaluations", "BIOMOD.models.out",
           function(obj, full.name = NULL, PA = NULL, run = NULL, algo = NULL, metric.eval = NULL) {
-            out <- load_stored_object(obj@models.evaluation)
-            if(nrow(out) == 0){
+            if(obj@models.evaluation@link == ''){
               cat("\n! models have no evaluations\n")
               return(invisible(NULL))
             } else {
+              out <- load_stored_object(obj@models.evaluation)
               keep_lines <- .filter_outputs.df(out, subset.list = list(full.name =  full.name, PA = PA
                                                                        , run = run, algo = algo
                                                                        , metric.eval = metric.eval))
@@ -606,11 +606,11 @@ setMethod("get_evaluations", "BIOMOD.models.out",
 
 setMethod("get_variables_importance", "BIOMOD.models.out",
           function(obj, full.name = NULL, PA = NULL, run = NULL, algo = NULL, expl.var = NULL) {
-            out <- load_stored_object(obj@variables.importance)
             if(obj@variables.importance@link == ''){
               cat("\n! models have no variables importance\n")
               return(invisible(NULL))
             } else {
+              out <- load_stored_object(obj@variables.importance)
               keep_lines <- .filter_outputs.df(out, subset.list = list(full.name =  full.name, PA = PA
                                                                        , run = run, algo = algo
                                                                        , expl.var = expl.var))
@@ -668,7 +668,7 @@ setMethod("get_variables_importance", "BIOMOD.models.out",
 ##'   determining whether x and y scales are shared among facet. Argument passed
 ##'   to \code{\link[ggplot2:facet_wrap]{facet_wrap}}. Possible values: 'fixed', 'free_x',
 ##'   'free_y', 'free'.
-##' @param size (\emph{optional, default} \code{0.75}) a numeric determing the
+##' @param size (\emph{optional, default} \code{0.75}) a numeric determining the
 ##'   size of points on the plots and passed to
 ##'   \code{\link[ggplot2:geom_point]{geom_point}}.
 ##' @param ... additional parameters to be passed to \code{\link{get_predictions}} 
@@ -1379,11 +1379,11 @@ setMethod("get_evaluations", "BIOMOD.ensemble.models.out",
           function(obj, full.name = NULL, merged.by.algo = NULL, merged.by.run = NULL
                    , merged.by.PA = NULL, filtered.by = NULL, algo = NULL, metric.eval = NULL)
           {
-            out <- load_stored_object(obj@models.evaluation)
-            if(nrow(out) == 0){
+            if(obj@models.evaluation@link == ''){
               cat("\n! models have no evaluations\n")
               return(invisible(NULL))
             } else {
+              out <- load_stored_object(obj@models.evaluation)
               keep_lines <- .filter_outputs.df(out, subset.list = list(full.name = full.name
                                                                        , merged.by.algo = merged.by.algo
                                                                        , merged.by.run = merged.by.run
@@ -1407,16 +1407,21 @@ setMethod("get_variables_importance", "BIOMOD.ensemble.models.out",
           function(obj, full.name = NULL, merged.by.algo = NULL, merged.by.run = NULL
                    , merged.by.PA = NULL, filtered.by = NULL, algo = NULL, expl.var = NULL)
           {
-            out <- load_stored_object(obj@variables.importance)
-            keep_lines <- .filter_outputs.df(out, subset.list = list(full.name = full.name
-                                                                     , merged.by.algo = merged.by.algo
-                                                                     , merged.by.run = merged.by.run
-                                                                     , merged.by.PA = merged.by.PA
-                                                                     , filtered.by = filtered.by
-                                                                     , algo = algo
-                                                                     , expl.var = expl.var))
-            out <- out[keep_lines, ]
-            return(out)
+            if(obj@variables.importance@link == ''){
+              cat("\n! models have no variables importance\n")
+              return(invisible(NULL))
+            } else {
+              out <- load_stored_object(obj@variables.importance)
+              keep_lines <- .filter_outputs.df(out, subset.list = list(full.name = full.name
+                                                                       , merged.by.algo = merged.by.algo
+                                                                       , merged.by.run = merged.by.run
+                                                                       , merged.by.PA = merged.by.PA
+                                                                       , filtered.by = filtered.by
+                                                                       , algo = algo
+                                                                       , expl.var = expl.var))
+              out <- out[keep_lines, ]
+              return(out)
+            }
           }
 )
 
