@@ -660,13 +660,13 @@ setMethod('predict2', signature(object = 'EMwmean_biomod2_model', newdata = "Spa
               stop("Model EMwmean was not computed because no single model was kept in ensemble modeling")
             }
             predfun <- function(newdata, on_0_1000, penalization_scores,
-                                mod.name, ...){
+                                mod.name, na.rm, ...){
               if (nlyr(newdata) == 1) {
                 return(newdata)
               } else {
                 return(
                   app(newdata, function(x) {
-                    wm <- sum(x * penalization_scores)
+                    wm <- sum(x * penalization_scores, na.rm = na.rm)
                     if (on_0_1000) { 
                       wm <- round(wm) 
                     }
@@ -691,10 +691,11 @@ setMethod('predict2', signature(object = 'EMwmean_biomod2_model', newdata = "dat
             if (ncol(newdata) < 1) {
               stop("Model EMwmean was not computed because no single model was kept in ensemble modeling")
             }
-            predfun <- function(newdata, on_0_1000, penalization_scores, ...){
-              out <- as.vector(
-                as.matrix(newdata) %*% penalization_scores
-              )
+            predfun <- function(newdata, on_0_1000, penalization_scores, na.rm, ...){
+              # out <- as.vector(
+              #   as.matrix(newdata) %*% penalization_scores
+              # )
+              out <- as.vector(rowSums(t(apply(as.matrix(newdata), 1, function(x) penalization_scores*x)), na.rm = na.rm))
               if (on_0_1000) { 
                 out <- round(out) 
               }
