@@ -564,15 +564,20 @@ get_var_range <- function(data)
   sub(pattern     = paste0(".*?_",sp.name), 
       replacement = "",
       x           = out.names)
-  out.binary <- grepl(pattern = "bin",
+  out.binary <- grepl(pattern = "bin\\.",
                       x = out.names)
-  out.filt <- grepl(pattern = "filt",
+  out.filt <- grepl(pattern = "filt\\.",
                     x = out.names)
   out.type <- ifelse(out.binary,
                      "bin",
                      ifelse(out.filt,
                             "filt", 
                             "out"))
+  # To avoid special case when the species name finish by "bin" (or "filt") ??
+  # out.format <- tools::file_ext(out.names)
+  # if(grepl(pattern = paste0(sp.name,"/.",out.format), x = out.names)){ 
+  #   out.type <- "out"
+  # }
   out.metric <- sapply(seq_len(length(out.names)), 
                        function(i){
                          if (out.type[i] == "out") {
