@@ -138,7 +138,7 @@
 ##' 
 ##' @seealso \code{\link[ENMeval]{get.block}}, \code{\link[dismo]{kfold}}, 
 ##' \code{\link{BIOMOD_FormatingData}}, \code{\link{BIOMOD_Modeling}}
-##' @family Secundary functions
+##' @family Secondary functions
 ##'
 ##'
 ##' @examples
@@ -822,7 +822,7 @@ setMethod('bm_CrossValidation_strat', signature(bm.format = "BIOMOD.formated.dat
                   if (strat == "x") { calib.pa_rep <- calib.x }
                 }
                 if (strat == "y" || strat == "both") {
-                  bands <- quantile(tmp.pa[ , 2], probs = seq(0, 100, 100 / k) / 100)
+                  bands <- quantile(tmp.pa.balance[ , 2], probs = seq(0, 100, 100 / k) / 100)
                   bands[1] <- -Inf
                   bands[k + 1] <- Inf
                   calib.y <- matrix(NA, nrow(tmp.pa), k)
