@@ -22,7 +22,7 @@
 ##' (\emph{a random number by default})
 ##' @param models a \code{vector} containing model names to be computed, must be among 
 ##' \code{ANN}, \code{CTA}, \code{FDA}, \code{GAM}, \code{GBM}, \code{GLM}, \code{MARS}, 
-##' \code{MAXENT}, \code{MAXNET}, \code{RF}, \code{SRE}, \code{XGBOOST}
+##' \code{MAXENT}, \code{MAXNET}, \code{RF}, \code{RFd}, \code{SRE}, \code{XGBOOST}
 ##' @param models.pa (\emph{optional, default} \code{NULL}) \cr 
 ##' A \code{list} containing for each model a \code{vector} defining which pseudo-absence datasets 
 ##' are to be used, must be among \code{colnames(bm.format@PA.table)}
@@ -49,7 +49,7 @@
 ##' 
 ##' @param model a \code{character} corresponding to the model name to be computed, must be either 
 ##' \code{ANN}, \code{CTA}, \code{FDA}, \code{GAM}, \code{GBM}, \code{GLM}, \code{MARS}, 
-##' \code{MAXENT}, \code{MAXNET}, \code{RF}, \code{SRE}, \code{XGBOOST}
+##' \code{MAXENT}, \code{MAXNET}, \code{RF}, \code{RFd}, \code{SRE}, \code{XGBOOST}
 ##' @param run.name a \code{character} corresponding to the model to be run (sp.name + pa.id + 
 ##' run.id)
 ##' @param dir.name (\emph{optional, default} \code{.}) \cr
@@ -91,7 +91,7 @@
 ##' \code{\link{bm_ModelingOptions}}, \code{\link{BIOMOD_Modeling}}, 
 ##' \code{\link{bm_MakeFormula}}, \code{\link{bm_SampleFactorLevels}}, 
 ##' \code{\link{bm_FindOptimStat}}, \code{\link{bm_VariablesImportance}}
-##' @family Secundary functions
+##' @family Secondary functions
 ##' 
 ##' 
 ##' @importFrom foreach foreach %do% %dopar% 
@@ -130,6 +130,15 @@ bm_RunModelsLoop <- function(bm.format,
     }
   }
   
+  # if (.getOS() == "windows" && "MAXENT" %in% models){
+  #   cl <- parallel::makeCluster(2)
+  #   doParallel::registerDoParallel(cl)
+  #   on.exit(parallel::stopCluster(cl))
+  # 
+  #   # env <- foreach:::.foreachGlobals
+  #   # rm(list=ls(name=env), pos=env)
+  # }
+  
   ## PREPARE DATA ---------------------------------------------------------------------------------
   list.data <- list()
   pa.list = sapply(colnames(calib.lines), function(x) strsplit(x, "_")[[1]][2])
@@ -162,7 +171,7 @@ bm_RunModelsLoop <- function(bm.format,
       }}}
   
   ## RUN models -----------------------------------------------------------------------------------
-  out <- foreach(ii = 1:length(list.data), .combine =) %dopar%
+  out <- foreach(ii = 1:length(list.data), .combine =, .errorhandling = "pass") %dopar%
     {
       cat('\n\n-=-=-=--=-=-=-', names(list.data)[ii], '\n')
       bm_RunModel(model = list.data[[ii]]$modi,
@@ -181,6 +190,18 @@ bm_RunModelsLoop <- function(bm.format,
                   do.progress = TRUE)
     }
   
+  for (iii in 1:length(out)){
+    if (names(out[[iii]][1]) == "message"){
+      out[[iii]] <- list(model = NULL,
+                       calib.failure = names(list.data)[iii],
+                       pred = NULL,
+                       pred.eval = NULL,
+                       evaluation = NULL,
+                       var.import = NULL)
+    }
+  }
+  
+  
   return(out)
 }
 
@@ -215,7 +236,8 @@ bm_RunModel <- function(model, run.name, dir.name = '.'
   opt_name <- grep(model, names(bm.options@options), value = TRUE)
   if (length(opt_name) == 1) {
     bm.opt <- bm.options@options[[opt_name]]
-  } else { stop("pitiprobleum") } ## Should not happen now
+  } else if (model == 'RF'){bm.opt <- bm.options@options[["RF.binary.randomForest.randomForest"]] }
+  else { stop("pitiprobleum") } ## Should not happen now
   
   if (length(grep("GAM", model)) == 1) {
     subclass_name <- paste0(bm.opt@model, "_", bm.opt@type, "_", bm.opt@package)
@@ -234,7 +256,9 @@ bm_RunModel <- function(model, run.name, dir.name = '.'
   if (model != "MAXENT") { ## ANY MODEL BUT MAXENT ------------------------------------------------
     
     ## PRELIMINAR ---------------------------------------------------
-    if (model %in% c("ANN", "MARS", "RF") & is.null(bm.opt.val$formula)) {
+
+
+    if (model %in% c("ANN", "MARS", "RF","RFd") & is.null(bm.opt.val$formula)) {
       bm.opt.val$formula <- bm_MakeFormula(resp.name = resp_name
                                            , expl.var = head(data_env)
                                            , type = 'simple'
@@ -247,9 +271,17 @@ bm_RunModel <- function(model, run.name, dir.name = '.'
       bm.opt.val$strata <- data_mod[calib.lines.vec, , drop = FALSE][ , resp_name]
       bm.opt.val$sampsize <- unlist(ifelse(!is.null(bm.opt.val$sampsize), list(bm.opt.val$sampsize), length(data_sp[calib.lines.vec]))) ## TOCHECK !!
     }
+    if (model == "RFd" && !is.null(bm.opt.val$type) && bm.opt.val$type == "classification") {
+      # defining occurrences as factor for doing classification and not regression in RF
+      data_mod <- data_mod %>% mutate_at(resp_name, factor)
+      bm.opt.val$strata <- data_mod[calib.lines.vec, , drop = FALSE][ , resp_name]
+      nb_presences <- summary(data_mod[calib.lines.vec,resp_name])[["1"]]
+      bm.opt.val$sampsize <- unlist(ifelse(!is.null(bm.opt.val$sampsize), list(bm.opt.val$sampsize), list(c("0" =nb_presences,"1" =nb_presences))))
+      bm.opt.val$replace <- unlist(ifelse(!is.null(bm.opt.val$replace), list(bm.opt.val$replace), TRUE))
+    }
     
     ## FILL data parameter ------------------------------------------
-    if (model %in% c("ANN", "CTA", "FDA", "GAM", "GBM", "MARS", "RF")) {
+    if (model %in% c("ANN", "CTA", "FDA", "GAM", "GBM", "MARS", "RF","RFd")) {
       bm.opt.val$data <- data_mod[calib.lines.vec, , drop = FALSE]
     } else if (model == "GLM") {
       bm.opt.val$data <- cbind(data_mod[calib.lines.vec, , drop = FALSE], 
@@ -281,7 +313,7 @@ bm_RunModel <- function(model, run.name, dir.name = '.'
     }
     
     ## REORGANIZE order of parameters -------------------------------
-    if (model %in% c("ANN", "MARS", "RF")) {
+    if (model %in% c("ANN", "MARS", "RF","RFd")) {
       bm.opt.val <- bm.opt.val[c("formula", "data", names(bm.opt.val)[which(!(names(bm.opt.val) %in% c("formula", "data")))])]
     }
     if (model %in% c("FDA")) {
@@ -333,7 +365,7 @@ bm_RunModel <- function(model, run.name, dir.name = '.'
     }
     
     ## POSTLIMINAR --------------------------------------------------
-    if (model == "RF" && !is.null(bm.opt.val$type) && bm.opt.val$type == "classification") {
+    if (model %in% c("RF","RFd") && !is.null(bm.opt.val$type) && bm.opt.val$type == "classification") {
       # canceling occurences class modifications
       data_mod <- data_mod %>% mutate_at(resp_name, function(.x) {
         .x %>% as.character() %>% as.numeric()
